nontree.visualize API documentation

# nontree.visualize

def plot(ntree, overlay=None, **kwargs):

Plots the layout of a NonTree (or derivative), using matplotlib.
Optionally plots an overlay of additional points on top, in a different color.

###### Parameters

- ntree: A NonTree (or derivative).
- overlay: A list of points in the shape of (x, y).
- kwargs: Keyword arguments, forwared to matplotlib.pyplot.figure().

def plot_demo():

Plots the layout of a demo NonTree, using matplotlib.
Also plots an overlay of additional points on top, in a different color.